<?php

/**
 * Register and Enqueue Bootstrap.
 *
 */
function cc_enqueue_bootstrap()
{
	wp_enqueue_style('bootstrap_css', '//cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css', array(), false);

	wp_enqueue_style('theme_bs_css',  get_stylesheet_directory_uri() . '/assets/theme-bs.css', array(), false);

	wp_enqueue_script('bootstrap_js', '//cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js', array(), '5.1.3', true);

	wp_enqueue_script('cc_js', get_stylesheet_directory_uri() . '/assets/js/theme.js', array('bootstrap_js'), '1.0.2', true);
}

if ( ! is_admin() ) {
	add_action('wp_loaded', 'cc_enqueue_bootstrap',5);
}

/**
 * Add editor css.
 *
 */
function cc_add_editor_styles()
{
	add_editor_style('editor-style.css');
}

add_action('after_setup_theme', 'cc_add_editor_styles');


/**
 * Add excerpt to pages.
 *
 */
function cc_support() {
	add_post_type_support('page', 'excerpt');
}

add_action('init', 'cc_support');



/**
 * Block Patterns
 *
 */

// Prevent loading patterns from the WordPress.org pattern directory 
add_filter( 'should_load_remote_block_patterns', '__return_false' );

// Remove Blockbase patterns
function cc_remove_blockbase_patterns() {
	remove_action( 'init', 'blockbase_register_block_patterns', 9 );
}
add_action( 'after_setup_theme', 'cc_remove_blockbase_patterns', 100 );

function cc_block_patterns() {

	// Remove WordPress core patterns
	remove_theme_support('core-block-patterns');

	// Add Canal Ciência pattern categories
	$block_pattern_categories = array(
		'canalciencia' => array( 'label' => 'Canal Ciência' ),
		'ilustracoes'=> array( 'label' => 'Ilustrações' ),
		'paginas'=> array( 'label' => 'Páginas' ),
		'componentes'=> array( 'label' => 'Componentes' ),
	);

	foreach ( $block_pattern_categories as $name => $properties ) {
		if ( ! WP_Block_Pattern_Categories_Registry::get_instance()->is_registered( $name ) ) {
			register_block_pattern_category( $name, $properties );
		}
	}
}
add_action( 'init', 'cc_block_patterns' );

function cc_block_styles() {
	register_block_style(
		'core/button',
		array(
			'name'  => 'cc-btn-text',
			'label' => __( 'Text button', 'tema-canal-ciencia' ),
			'style_handle' => 'blockbase-child-styles',
		)
	);
	register_block_style(
		'core/button',
		array(
			'name'  => 'cc-btn-more',
			'label' => __( 'More button', 'tema-canal-ciencia' ),
			'style_handle' => 'blockbase-child-styles',
		)
	);
	register_block_style(
		'core/button',
		array(
			'name'  => 'cc-btn-tonal',
			'label' => __( 'Tonal button', 'tema-canal-ciencia' ),
			'style_handle' => 'blockbase-child-styles',
		)
	);
}
add_action( 'init', 'cc_block_styles' );

function cc_get_parent_link($class = 'has-cc-blue-70-color') {
	global $post;
	if ( $post->post_parent ) {
	
		$parent_link = '<a class="'.$class.'" href="'. esc_url( get_the_permalink( $post->post_parent )).'">'. get_the_title( $post->post_parent ).'</a>';
	
		return $parent_link;
	}
}

function cc_parent_link_shortcode($atts) {

	$default = array (
		'class' => 'has-cc-blue-70-color',
		'markup' => null
	);

	$a = shortcode_atts($default,$atts);

	if( is_null($a['markup']) ) {
		$output = cc_get_parent_link(esc_attr( $a['class'] ));
	} else {
		$output = '<' . esc_attr( $a['markup'] ). ' class="cc-parent-link">' . cc_get_parent_link(esc_attr( $a['class'] )) . '</' . esc_attr( $a['markup'] ). '>' ;
	}

	return $output;
}

function cc_shortcodes_init() {
	add_shortcode('parent_link','cc_parent_link_shortcode');
}
add_action('init', 'cc_shortcodes_init');

function cc_get_area_do_conhecimento() {

	$areaDoConhecimento = isset($_GET['area-do-conhecimento']) ? sanitize_text_field($_GET['area-do-conhecimento']) : '';

	return $areaDoConhecimento;
}

/**
 * This function modifies the main WordPress query to remove 
 * pages from search results.
 *
 * @param object $query The main WordPress query.
 */
function cc_exclude_pages_from_search_results( $query ) {
    if ( $query->is_main_query() && $query->is_search() && ! is_admin() ) {
        $query->set( 'post_type', array( 'post' ) );
    }    
}
add_action( 'pre_get_posts', 'cc_exclude_pages_from_search_results' );